@@ -3,8 +3,6 @@
  *
  * Written 1999 by Wolfgang G. Reissnegger and Werner Almesberger
  *
- * $Id: canon.h 9396 2006-11-14 20:38:16Z marcusmeissner $
- *
  */
 
 #ifndef _CANON_H
@@ -193,7 +191,6 @@ typedef enum {
 } canonCaptureSupport;
 
 
-#ifdef CANON_EXPERIMENTAL_20D
 /**
  * These ISO, shutter speed, aperture, etc. settings are correct for the 
  * EOS 5D; unsure about other cameras.
@@ -211,7 +208,8 @@ typedef enum {
 	ISO_800 = 0x60,
 	ISO_1000 = 0x63,
 	ISO_1250 = 0x65,
-	ISO_1600 = 0x68
+	ISO_1600 = 0x68,
+	ISO_3200 = 0x70
 } canonIsoState;
 
 struct canonIsoStateStruct {
@@ -220,6 +218,12 @@ struct canonIsoStateStruct {
 };
 
 typedef enum {
+	APERTURE_F1_4 = 0x10,
+	APERTURE_F1_6 = 0x13,
+	APERTURE_F1_8 = 0x15,
+	APERTURE_F2_0 = 0x18,
+	APERTURE_F2_2 = 0x1b,
+	APERTURE_F2_5 = 0x1d,
 	APERTURE_F2_8 = 0x20,
 	APERTURE_F3_2 = 0x23,
 	APERTURE_F3_5 = 0x25,
@@ -238,7 +242,10 @@ typedef enum {
 	APERTURE_F16 = 0x48,
 	APERTURE_F18 = 0x4b,
 	APERTURE_F20 = 0x4d,
-	APERTURE_F22 = 0x50
+	APERTURE_F22 = 0x50,
+	APERTURE_F25 = 0x53,
+	APERTURE_F29 = 0x55,
+	APERTURE_F32 = 0x58,
 } canonApertureState;
 
 struct canonApertureStateStruct {
@@ -344,11 +351,6 @@ struct canonFocusModeStateStruct {
 	char *label;
 };
 
-
-#endif /* CANON_EXPERIMENTAL_20D */
-
-/* The following defines are for the CANON_EXPERIMENTAL_20D */
-
 /* Size of the release parameter block */
 #define RELEASE_PARAMS_LEN  0x2f
 
@@ -362,9 +364,6 @@ struct canonFocusModeStateStruct {
 #define APERTURE_INDEX      0x1c
 #define SHUTTERSPEED_INDEX  0x1e
 
-/* end of CANON_EXPERIMENTAL_20D defines */
-
-
 /**
  * canonCaptureSizeClass:
  * @CAPTURE_COMPATIBILITY: operate in the traditional gphoto2 mode
@@ -453,12 +452,12 @@ struct _CameraPrivateLibrary
 	canonCaptureSizeClass capture_size; /* Size class for remote-
                                                captured images */
 
-#ifdef CANON_EXPERIMENTAL_20D
+	unsigned int body_id;	/* hardware serial number for some cameras */
+
 	unsigned char release_params[RELEASE_PARAMS_LEN]; /* "Release 
 							     parameters:"
 							     ISO, aperture, 
 							     etc */
-#endif
 
 	int secondary_image; /* Should we attempt to download a 
 				secondary image? (e.g., RAW + JPEG) */
@@ -575,7 +574,7 @@ typedef enum {
 #define GP_PORT_DEFAULT_RETURN_INTERNAL(return_statement) \
 		default: \
 			gp_context_error (context, _("Don't know how to handle " \
-					     "camera->port->type value %i aka 0x%x" \
+					     "camera->port->type value %i aka 0x%x " \
 					     "in %s line %i."), camera->port->type, \
 					     camera->port->type, __FILE__, __LINE__); \
 			return_statement; \
@@ -633,14 +632,11 @@ int canon_int_get_thumbnail(Camera *camera, const char *name, unsigned char **re
 int canon_int_put_file(Camera *camera, CameraFile *file, char *destname, char *destpath, GPContext *context);
 int canon_int_set_file_attributes(Camera *camera, const char *file, const char *dir, canonDirentAttributeBits attrs, GPContext *context);
 int canon_int_delete_file(Camera *camera, const char *name, const char *dir, GPContext *context);
-#ifdef CANON_EXPERIMENTAL_SET_RELEASE_PARAMS
 int canon_int_set_shutter_speed(Camera *camera, canonShutterSpeedState shutter_speed, GPContext *context);
 int canon_int_set_iso(Camera *camera, canonIsoState iso, GPContext *context);
 int canon_int_set_aperture(Camera *camera, canonApertureState aperture, GPContext *context);
 int canon_int_set_focus_mode (Camera *camera, canonFocusModeState focus_mode, GPContext *context);
 int canon_int_set_resolution (Camera *camera, unsigned char res_byte1, unsigned char res_byte2, unsigned char res_byte3, GPContext *context);
-#endif
-int canon_serial_end(Camera *camera);
 int canon_serial_off(Camera *camera);
 int canon_int_get_time(Camera *camera, time_t *camera_time, GPContext *context);
 int canon_int_set_time(Camera *camera, time_t date, GPContext *context);
@@ -653,30 +649,11 @@ int canon_int_end_remote_control(Camera *camera, GPContext *context);
 /*
  * introduced for capturing
  */
-int
-canon_int_get_picture_abilities (Camera *camera, GPContext *context);
-#ifdef CANON_EXPERIMENTAL_20D
 int canon_int_get_release_params (Camera *camera, GPContext *context);
-#endif
-#ifdef CANON_EXPERIMENTAL_SET_RELEASE_PARAMS
-int canon_int_set_release_params(Camera *camera, GPContext *context);
-#endif
-int
-canon_int_pack_control_subcmd (unsigned char *payload, unsigned int subcmd,
-			       int word0, int word1,
-			       char *desc);
-int
-canon_int_do_control_command (Camera *camera, unsigned int subcmd, int a, int b);
-int
-canon_int_do_control_dialogue (Camera *camera, unsigned int subcmd, int a, int b, unsigned char **response_handle, unsigned int *datalen);
-int
-canon_int_do_control_dialogue_payload (Camera *camera, unsigned char *payload, unsigned int payloadlen, unsigned char **response_handle, unsigned int *datalen);
-
 
 
 /* path conversion - needs drive letter, and therefore cannot be moved
  * to util.c */
-const char *canon2gphotopath(Camera *camera, const char *path);
 const char *gphoto2canonpath(Camera *camera, const char *path, GPContext *context);
 
 const char *canon_int_filename2thumbname (Camera *camera, const char *filename);
