@@ -25,8 +25,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <gphoto2-result.h>
-#include <gphoto2-port-log.h>
+#include <gphoto2/gphoto2-result.h>
+#include <gphoto2/gphoto2-port-log.h>
 
 #include "konica.h"
 
