@@ -21,7 +21,7 @@
 #ifndef __LG_GSM_H__
 #define __LG_GSM_H__
 
-#include <libgphoto2_port/gphoto2-port.h>
+#include <gphoto2/gphoto2-port.h>
 
 typedef unsigned char Info;
 
@@ -30,7 +30,7 @@ typedef enum {
 } Model;
 
 int lg_gsm_init              (GPPort *port, Model *model, Info *info);
-int lg_gsm_get_picture_size  (GPPort *port, int pic);
+unsigned int lg_gsm_get_picture_size  (GPPort *port, int pic);
 int lg_gsm_read_picture_data (GPPort *port, char *data, int size, int n);
 int lg_gsm_list_files (GPPort *port, CameraList *list);
 
