@@ -44,8 +44,8 @@
 
 #include <_stdint.h>
 
-#include <gphoto2-result.h>
-#include <gphoto2-port-log.h>
+#include <gphoto2/gphoto2-result.h>
+#include <gphoto2/gphoto2-port-log.h>
 
 #define GP_MODULE "sierra"
 
