@@ -26,8 +26,8 @@
 #include <string.h>
 #include <time.h>
 
-#include <gphoto2-library.h>
-#include <gphoto2-port-log.h>
+#include <gphoto2/gphoto2-library.h>
+#include <gphoto2/gphoto2-port-log.h>
 
 #include "sierra-desc.h"
 #include "library.h"
@@ -53,13 +53,13 @@
 
 #define GP_MODULE "sierra"
 
-int get_jpeg_data(const char *data, int data_size, char **jpeg_data, int *jpeg_size);
+static int get_jpeg_data(const char *data, int data_size, char **jpeg_data, int *jpeg_size);
 
 /* Useful markers */
-const char JPEG_SOI_MARKER[]  = { (char)0xFF, (char)0xD8, '\0' };
-const char JPEG_SOF_MARKER[]  = { (char)0xFF, (char)0xD9, '\0' };
-const char JPEG_APP1_MARKER[] = { (char)0xFF, (char)0xE1, '\0' };
-const char TIFF_SOI_MARKER[]  = { (char)0x49, (char)0x49, (char)0x2A, (char)0x00, (char)0x08, '\0' };
+static const char JPEG_SOI_MARKER[]  = { (char)0xFF, (char)0xD8, '\0' };
+static const char JPEG_SOF_MARKER[]  = { (char)0xFF, (char)0xD9, '\0' };
+static const char JPEG_APP1_MARKER[] = { (char)0xFF, (char)0xE1, '\0' };
+static const char TIFF_SOI_MARKER[]  = { (char)0x49, (char)0x49, (char)0x2A, (char)0x00, (char)0x08, '\0' };
 
 static struct {
 	const char *manuf;
@@ -70,105 +70,113 @@ static struct {
 	SierraFlags  flags;
 	struct CameraDesc const *cam_desc;
 } sierra_cameras[] = {
-	/* Camera Model, Sierra Model, USB(vendor id, product id,
-	   USB wrapper protocol) */ 
+	/* Manufacturer, Camera Model, Sierra Model,
+	   USBvendor id, USB product id,
+	   USB wrapper protocol, CameraDesc) */ 
 	{"Agfa", "ePhoto 307", 	SIERRA_MODEL_DEFAULT, 	0, 0,
-					SIERRA_NO_51 },
-	{"Agfa", "ePhoto 780", 	SIERRA_MODEL_DEFAULT, 	0, 0, 0 },
+		SIERRA_NO_51, NULL},
+	{"Agfa", "ePhoto 780", 	SIERRA_MODEL_DEFAULT, 	0, 0, 0, NULL },
 	{"Agfa", "ePhoto 780C",	SIERRA_MODEL_DEFAULT,	0, 0,
-					SIERRA_NO_51 | SIERRA_LOW_SPEED },
-	{"Agfa", "ePhoto 1280",	SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Agfa", "ePhoto 1680", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Apple", "QuickTake 200", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Chinon", "ES-1000", 	SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Epson", "PhotoPC 500", SIERRA_MODEL_EPSON,	0, 0, 0 },
-	{"Epson", "PhotoPC 550", SIERRA_MODEL_EPSON,	0, 0, 0 },
-	{"Epson", "PhotoPC 600", SIERRA_MODEL_EPSON,	0, 0, 0 },
+		SIERRA_NO_51 | SIERRA_LOW_SPEED, NULL },
+	{"Agfa", "ePhoto 1280",	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Agfa", "ePhoto 1680", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Apple", "QuickTake 200", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Chinon", "ES-1000", 	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Epson", "PhotoPC 500", SIERRA_MODEL_EPSON,	0, 0, 0, NULL },
+	{"Epson", "PhotoPC 550", SIERRA_MODEL_EPSON,	0, 0, 0, NULL },
+	{"Epson", "PhotoPC 600", SIERRA_MODEL_EPSON,	0, 0, 0, NULL },
 	{"Epson", "PhotoPC 650", SIERRA_MODEL_EPSON,	0, 0,
-					SIERRA_NO_51 | SIERRA_LOW_SPEED },
-	{"Epson", "PhotoPC 700", SIERRA_MODEL_EPSON,	0, 0, SIERRA_NO_51 },
-	{"Epson", "PhotoPC 800", SIERRA_MODEL_EPSON,	0, 0, 0 },
-	{"Epson", "PhotoPC 850z", SIERRA_MODEL_EPSON,     0x4b8, 0x402, 0},
+					SIERRA_NO_51 | SIERRA_LOW_SPEED, NULL },
+	{"Epson", "PhotoPC 700", SIERRA_MODEL_EPSON,	0, 0, SIERRA_NO_51, NULL },
+	{"Epson", "PhotoPC 800", SIERRA_MODEL_EPSON,	0, 0, 0, NULL },
+	{"Epson", "PhotoPC 850z", SIERRA_MODEL_EPSON,     0x4b8, 0x402, 0, NULL},
 	{"Epson", "PhotoPC 3000z", SIERRA_MODEL_CAM_DESC,	0x4b8, 0x403, 0, &ep3000z_cam_desc},
-	{"Nikon", "CoolPix 100", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Nikon", "CoolPix 300", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Nikon", "CoolPix 700", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Nikon", "CoolPix 800", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
+	{"Nikon", "CoolPix 100", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Nikon", "CoolPix 300", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Nikon", "CoolPix 700", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Nikon", "CoolPix 800", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
 	{"Nikon", "CoolPix 880",SIERRA_MODEL_CAM_DESC,	0x04b0, 0x0103, 0,
 							&cp880_cam_desc},
-	{"Nikon", "CoolPix 900", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Nikon", "CoolPix 900S", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Nikon", "CoolPix 910", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Nikon", "CoolPix 950", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Nikon", "CoolPix 950S", SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Nikon", "CoolPix 990", SIERRA_MODEL_DEFAULT,	0x04b0, 0x0102, 0},
+	{"Nikon", "CoolPix 900", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Nikon", "CoolPix 900S", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Nikon", "CoolPix 910", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Nikon", "CoolPix 950", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Nikon", "CoolPix 950S", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Nikon", "CoolPix 990", SIERRA_MODEL_DEFAULT,	0x04b0, 0x0102, 0, NULL},
 	{"Nikon", "CoolPix 995",   SIERRA_MODEL_CAM_DESC, 0x04b0, 0x0104,
 						SIERRA_WRAP_USB_OLYMPUS,
 							&cp995_cam_desc},
-#if 0
+
 	{"Nikon", "CoolPix 2500 (Sierra Mode)", SIERRA_MODEL_CAM_DESC, 0x04b0, 0x0108,
 						SIERRA_WRAP_USB_NIKON | SIERRA_NO_51,
 							&cp2500_cam_desc},
-#endif
+
+	{"Nikon", "CoolPix 2100 (Sierra Mode)", SIERRA_MODEL_CAM_DESC, 0x04b0, 0x0116,
+						SIERRA_WRAP_USB_NIKON | SIERRA_NO_51,
+							&cp2500_cam_desc},
+
 	{"Nikon", "CoolPix 4300 (Sierra Mode)", SIERRA_MODEL_CAM_DESC, 0x04b0, 0x010e,
 						SIERRA_WRAP_USB_NIKON | SIERRA_NO_51,
 							&cp880_cam_desc},
 	{"Nikon", "CoolPix 3500 (Sierra Mode)", SIERRA_MODEL_CAM_DESC, 0x04b0, 0x0110,
 						SIERRA_WRAP_USB_NIKON | SIERRA_NO_51,
 							&cp880_cam_desc},
-	{"Olympus", "D-100Z", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-200L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-220L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-300L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-320L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-330R", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-340L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-340R", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-360L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-400L Zoom", SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-450Z", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-460Z", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-500L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-600L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-600XL", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "D-620L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-400", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-400L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-410", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-410L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-420", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-420L", 	SIERRA_MODEL_OLYMPUS,	0, 0, SIERRA_MID_SPEED },
+	{"Nikon", "D100 (Sierra Mode)", SIERRA_MODEL_CAM_DESC, 0x04b0, 0x0401,
+						SIERRA_WRAP_USB_NIKON | SIERRA_NO_51,
+							&cp880_cam_desc},
+	{"Olympus", "D-100Z", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-200L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-220L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-300L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-320L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-330R", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-340L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-340R", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-360L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-400L Zoom", SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-450Z", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-460Z", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-500L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-600L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-600XL", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "D-620L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-400", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-400L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-410", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-410L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-420", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-420L", 	SIERRA_MODEL_OLYMPUS,	0, 0, SIERRA_MID_SPEED, NULL },
 	{"Olympus", "C-700UZ",	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x105,
 					SIERRA_WRAP_USB_OLYMPUS, &oly3040_cam_desc},
 	{"Olympus", "C-750UZ",	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x105,
 					SIERRA_WRAP_USB_OLYMPUS, &oly750uz_cam_desc},
 	{"Olympus", "C-770UZ",	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x105,
 					SIERRA_WRAP_USB_OLYMPUS, &oly750uz_cam_desc},
-	{"Olympus", "C-800", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-800L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-820", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
+	{"Olympus", "C-800", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-800L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-820", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
 	{"Olympus", "C-820L", 	SIERRA_MODEL_OLYMPUS,	0, 0,
-					SIERRA_MID_SPEED },
-	{"Olympus", "C-830L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-840L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-860L",	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-900 Zoom", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-900L Zoom", SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
+					SIERRA_MID_SPEED, NULL },
+	{"Olympus", "C-830L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-840L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-860L",	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-900 Zoom", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-900L Zoom", SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
 
 	/* http://sourceforge.net/tracker/index.php?func=detail&aid=1082569&group_id=8874&atid=358874 
 	 * strangely only works with low speed
 	 */
-	{"Olympus", "C-990 Zoom", 	SIERRA_MODEL_OLYMPUS,	0, 0, SIERRA_LOW_SPEED },
-	{"Olympus", "C-1000L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-1400L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-1400XL", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-2000Z", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
-	{"Olympus", "C-2020Z",	SIERRA_MODEL_OLYMPUS,	0, 0, 0 },
+	{"Olympus", "C-990 Zoom", 	SIERRA_MODEL_OLYMPUS,	0, 0, SIERRA_LOW_SPEED, NULL },
+	{"Olympus", "C-1000L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-1400L", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-1400XL", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-2000Z", 	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
+	{"Olympus", "C-2020Z",	SIERRA_MODEL_OLYMPUS,	0, 0, 0, NULL },
 	{"Olympus", "C-2040Z", 	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x105,
 					SIERRA_WRAP_USB_OLYMPUS, &oly3040_cam_desc},
 	{"Olympus", "C-2100UZ", SIERRA_MODEL_CAM_DESC, 0x07b4, 0x100, 0,
 					&oly3040_cam_desc},
-	{"Olympus", "C-2500L",     SIERRA_MODEL_OLYMPUS,   0, 0, 0 },
+	{"Olympus", "C-2500L",     SIERRA_MODEL_OLYMPUS,   0, 0, 0, NULL },
 	/*
 	 * Note: The 3000z can't be auto selected, as it has the same USB
 	 * id as the 2040 (and others, but the others are still using the
@@ -187,39 +195,46 @@ static struct {
 					SIERRA_WRAP_USB_OLYMPUS, &oly3040_cam_desc},
 	{"Olympus", "C-5050Z", 	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x105,
 					SIERRA_WRAP_USB_OLYMPUS, &oly3040_cam_desc},
+	{"Olympus", "SP-500UZ", 	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x109,
+				SIERRA_WRAP_USB_OLYMPUS, &olysp500uz_cam_desc},
 	{"Olympus", "C-370Z", 	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x109,
 				SIERRA_WRAP_USB_OLYMPUS, &oly3040_cam_desc},
 	{"Olympus", "X-450", 	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x109,
 				SIERRA_WRAP_USB_OLYMPUS, &oly3040_cam_desc},
 	{"Olympus", "D-535Z", 	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x109,
 				SIERRA_WRAP_USB_OLYMPUS, &oly3040_cam_desc},
+	{"Olympus", "fe-200", 	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x109,
+				SIERRA_WRAP_USB_OLYMPUS, &oly3040_cam_desc},
 
-	{"Panasonic", "Coolshot NV-DCF5E", SIERRA_MODEL_DEFAULT, 0, 0, 0 },
+	{"Panasonic", "Coolshot NV-DCF5E", SIERRA_MODEL_DEFAULT, 0, 0, 0, NULL },
 
-	{"Pentax", "Optio 450", SIERRA_MODEL_DEFAULT, 0x0a17,0x0007, SIERRA_WRAP_USB_PENTAX },
-	{"Pentax", "Optio 33WR", SIERRA_MODEL_DEFAULT, 0x0a17,0x0009, SIERRA_WRAP_USB_PENTAX },
+	{"Pentax", "Optio 450", SIERRA_MODEL_DEFAULT, 0x0a17,0x0007, SIERRA_WRAP_USB_PENTAX, NULL },
+	{"Pentax", "Optio 33WR", SIERRA_MODEL_DEFAULT, 0x0a17,0x0009, SIERRA_WRAP_USB_PENTAX, NULL },
 
-	{"Polaroid", "PDC 640", 	SIERRA_MODEL_DEFAULT,	0, 0, 0 },
+	{"Polaroid", "PDC 640", 	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
 	{"Polaroid", "PDC 2300Z", SIERRA_MODEL_DEFAULT, 0x0546, 0x0daf,
-					SIERRA_SKIP_INIT },
-	{"Sanyo", "DSC-X300", 	SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Sanyo", "DSC-X350", 	SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Sanyo", "VPC-G200", 	SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Sanyo", "VPC-G200EX", 	SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Sanyo", "VPC-G210", 	SIERRA_MODEL_DEFAULT,	0, 0, 0 },
-	{"Sanyo", "VPC-G250", 	SIERRA_MODEL_DEFAULT,	0, 0, SIERRA_NO_51 },
-	{"Sierra Imaging", "SD640",SIERRA_MODEL_DEFAULT,	0, 0, 0 },
+					SIERRA_SKIP_INIT, NULL },
+	{"Sanyo", "DSC-X300", 	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Sanyo", "DSC-X350", 	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Sanyo", "VPC-G200", 	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Sanyo", "VPC-G200EX", 	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Sanyo", "VPC-G210", 	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	{"Sanyo", "VPC-G250", 	SIERRA_MODEL_DEFAULT,	0, 0, SIERRA_NO_51, NULL },
+	{"Sierra Imaging", "SD640",SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
 	/*
 	 * Added by Sean Bruno on July 22, 2004 to support the Toshiba
 	 * cameras below.
 	 */
 	{"Toshiba", "PDR-M60", SIERRA_MODEL_DEFAULT, 0x1132, 0x4332,
-		SIERRA_NO_51 | SIERRA_NO_REGISTER_40 | SIERRA_NO_USB_CLEAR},
+		SIERRA_NO_51 | SIERRA_NO_REGISTER_40 | SIERRA_NO_USB_CLEAR,
+		NULL},
 	{"Toshiba", "PDR-M61", SIERRA_MODEL_DEFAULT, 0x1132, 0x4335,
-		SIERRA_NO_51 | SIERRA_NO_REGISTER_40 | SIERRA_NO_USB_CLEAR},
+		SIERRA_NO_51 | SIERRA_NO_REGISTER_40 | SIERRA_NO_USB_CLEAR,
+		NULL},
 	{"Toshiba", "PDR-M65", SIERRA_MODEL_DEFAULT, 0x1132, 0x4334,
-		SIERRA_NO_51 | SIERRA_NO_REGISTER_40 | SIERRA_NO_USB_CLEAR},
-	{NULL, NULL, 0,	0, 0, 0}
+		SIERRA_NO_51 | SIERRA_NO_REGISTER_40 | SIERRA_NO_USB_CLEAR,
+		NULL},
+	{NULL, NULL, 0,	0, 0, 0, NULL}
 };
 
 static struct {
@@ -1575,17 +1590,17 @@ camera_get_config_epson (Camera *camera, CameraWidget **window, GPContext *conte
 	ret = sierra_get_int_register (camera, 1, &value, context);
         if (ret >= 0) {
 		gp_widget_new (GP_WIDGET_RADIO, _("Resolution"), &child);
-		gp_widget_add_choice (child, _("Standard"));
-		gp_widget_add_choice (child, _("Fine"));
-		gp_widget_add_choice (child, _("SuperFine"));
+		gp_widget_add_choice (child, _("standard"));
+		gp_widget_add_choice (child, _("fine"));
+		gp_widget_add_choice (child, _("superfine"));
 		gp_widget_add_choice (child, _("HyPict"));
 		
                 switch (value) {
-		case 1: strcpy (t, _("Standard"));
+		case 1: strcpy (t, _("standard"));
 			break;
-                case 2: strcpy (t, _("Fine"));
+                case 2: strcpy (t, _("fine"));
 			break;
-                case 3: strcpy (t, _("SuperFine"));
+                case 3: strcpy (t, _("superfine"));
 			break;
                 case 34: strcpy (t, _("HyPict"));
 			break;
@@ -1786,11 +1801,11 @@ camera_set_config_epson (Camera *camera, CameraWidget *window, GPContext *contex
 	if ((gp_widget_get_child_by_label (window, _("Resolution"), &child)
 	     >= 0) && gp_widget_changed (child)) {
 		gp_widget_get_value (child, &value);
-		if (strcmp (value, _("Standard")) == 0) {
+		if (strcmp (value, _("standard")) == 0) {
 			i = 1;
-		} else if (strcmp (value, _("Fine")) == 0) {
+		} else if (strcmp (value, _("fine")) == 0) {
 			i = 2;
-		} else if (strcmp (value, _("SuperFine")) == 0) {
+		} else if (strcmp (value, _("superfine")) == 0) {
 			i = 3;
 		} else if (strcmp (value, _("HyPict")) == 0) {
 			i = 34;
@@ -1916,39 +1931,37 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *c)
 	/* Get all the string-related info */
 
 	if (sierra_get_string_register (camera, 27, 0, NULL, t, &v, c) >= 0)
-		sprintf (buf, _("%sCamera Model: %s\n"), buf, t);
+		sprintf (buf+strlen(buf), _("Camera Model: %s\n"), t);
 	if (sierra_get_string_register (camera, 48, 0, NULL, t, &v, c) >= 0)
-		sprintf (buf, _("%sManufacturer: %s\n"), buf, t);
+		sprintf (buf+strlen(buf), _("Manufacturer: %s\n"), t);
 	if (sierra_get_string_register (camera, 22, 0, NULL, t, &v, c) >= 0)
-		sprintf (buf, _("%sCamera ID: %s\n"), buf, t);
+		sprintf (buf+strlen(buf), _("Camera ID: %s\n"), t);
 	if (sierra_get_string_register (camera, 25, 0, NULL, t, &v, c) >= 0)
-		sprintf (buf, _("%sSerial Number: %s\n"), buf, t);
+		sprintf (buf+strlen(buf), _("Serial Number: %s\n"), t);
 	if (sierra_get_string_register (camera, 26, 0, NULL, t, &v, c) >= 0)
-		sprintf (buf, _("%sSoftware Rev.: %s\n"), buf, t);
+		sprintf (buf+strlen(buf), _("Software Rev.: %s\n"), t);
 
 	/* Get all the integer information */
 	if (camera->pl->flags & SIERRA_NO_REGISTER_40) {
 		if (sierra_get_int_register(camera, 10, &v, c) >= 0)
-			sprintf (buf, _("%sFrames Taken: %i\n"), buf, v);
+			sprintf (buf+strlen(buf), _("Frames Taken: %i\n"), v);
 	} else {
 		if (sierra_get_int_register(camera, 40, &v, c) >= 0)
-			sprintf (buf, _("%sFrames Taken: %i\n"), buf, v);
+			sprintf (buf+strlen(buf), _("Frames Taken: %i\n"), v);
 	}
 	if (sierra_get_int_register(camera, 11, &v, c) >= 0)
-		sprintf (buf, _("%sFrames Left: %i\n"), buf, v);
+		sprintf (buf+strlen(buf), _("Frames Left: %i\n"), v);
 	if (sierra_get_int_register(camera, 16, &v, c) >= 0)
-		sprintf (buf, _("%sBattery Life: %i\n"), buf, v);
+		sprintf (buf+strlen(buf), _("Battery Life: %i\n"), v);
 	if (sierra_get_int_register(camera, 28, &v, c) >= 0)
-		sprintf (buf, _("%sMemory Left: %i bytes\n"), buf, v);
+		sprintf (buf+strlen(buf), _("Memory Left: %i bytes\n"), v);
 
 	/* Get date */
 	if (sierra_get_int_register (camera, 2, &v, c) >= 0) {
 		time_t vtime = v;
-		sprintf (buf, _("%sDate: %s"), buf, ctime (&vtime));
+		sprintf (buf+strlen(buf), _("Date: %s"), ctime (&vtime));
 	}
-
 	strcpy (summary->text, buf);
-
 	return (camera_stop (camera, c));
 }
 
@@ -1983,17 +1996,15 @@ camera_manual (Camera *camera, CameraText *manual, GPContext *context)
 		    "(1) Camera Configuration:\n"
 		    "    A value of 0 will take the default one (auto).\n"
 		    "(2) Olympus C-3040Z (and possibly also the C-2040Z\n"
-		    "    and others) have a USB PC Control mode. In order\n"
-		    "    to use this mode, the camera must be switched\n"
-		    "    into 'USB PC control mode'. To get to the menu\n"
-		    "    for switching modes, turn on the camera, open\n"
+		    "    and others) have a USB PC Control mode. To switch\n"
+		    "    to this mode, turn on the camera, open\n"
 		    "    the memory card access door and then press and\n"
 		    "    hold both of the menu and LCD buttons until the\n"
 		    "    camera control menu appears. Set it to ON.\n"
 		    "(3) If you switch the 'LCD mode' to 'Monitor' or\n"
 		    "    'Normal', don't forget to switch it back to 'Off'\n"
 		    "    before disconnecting. Otherwise you cannot use\n"
-		    "    the camera's buttons. If you end up with this\n"
+		    "    the camera's buttons. If you end up in this\n"
 		    "    state, you should reconnect the camera to the\n"
 		    "    PC and switch LCD to 'Off'."));
 		break;
@@ -2011,7 +2022,7 @@ camera_about (Camera *camera, CameraText *about, GPContext *context)
 		_("sierra SPARClite library\n"
 		"Scott Fritzinger <scottf@unr.edu>\n"
 		"Support for sierra-based digital cameras\n"
-		"including Olympus, Nikon, Epson, Pentax, and others.\n"
+		"including Olympus, Nikon, Epson, and Pentax.\n"
 		"\n"
 		"Thanks to Data Engines (www.dataengines.com)\n"
 		"for the use of their Olympus C-3030Z for USB\n"
