@@ -252,6 +252,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	unsigned char *ppm, *ptr;
 	unsigned char gtable[256];
 	int size;
+	int this_cam_tile;
 
 	if (GP_FILE_TYPE_EXIF ==type) return GP_ERROR_FILE_EXISTS;
 
@@ -356,38 +357,41 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		 */
 		ppm = malloc (w * h * 3 + 256); /* room for data + header */
 		if (!ppm) { return GP_ERROR_NO_MEMORY; }
-    		sprintf (ppm,
+    		sprintf ((char *)ppm,
 			"P6\n"
 			"# CREATOR: gphoto2, SQ905 library\n"
 			"%d %d\n"
 			"255\n", w, h);
-		size = strlen (ppm);
+		size = strlen ((char *)ppm);
 		ptr = ppm + size;
-		if (comp_ratio>1) {
-			sq_decompress (camera->pl->model, ptr, frame_data, w, h, entry);			
-			sq_postprocess(camera->pl,w, h, ptr, entry);
-		}
-		size = size + (w * h * 3);
-		GP_DEBUG ("size = %i\n", size);
 
-		if ( comp_ratio == 1) {
 			switch (camera->pl->model) {
 			case SQ_MODEL_POCK_CAM:
-				gp_bayer_decode (frame_data, w , h , 
-						    ptr, BAYER_TILE_GBRG);
+			case SQ_MODEL_MAGPIX:
+				this_cam_tile = BAYER_TILE_GBRG;
 				break;
 			default:
-				gp_bayer_decode (frame_data, w , h , 
-						    ptr, BAYER_TILE_BGGR);
+				this_cam_tile = BAYER_TILE_BGGR;
 				break;
 			}
-			gp_gamma_fill_table (gtable, .5); 
-			gp_gamma_correct_single (gtable, ptr, w * h); 
-    		} 
+		size = size + (w * h * 3);
+		GP_DEBUG ("size = %i\n", size);
+		if (comp_ratio>1) {
+			rawdata = malloc (w*h);
+			if (!rawdata) return GP_ERROR_NO_MEMORY;
+			sq_decompress (camera->pl->model, rawdata, 
+						frame_data, w, h);			
+			gp_gamma_fill_table (gtable, .65); 
+		} else {
+			rawdata = frame_data;
+			gp_gamma_fill_table (gtable, .55); 
+		}
+		gp_bayer_decode (rawdata, w , h , ptr, this_cam_tile);
+		gp_gamma_correct_single (gtable, ptr, w * h); 
 
 		gp_file_set_mime_type (file, GP_MIME_PPM);
     		gp_file_set_name (file, filename); 
-		gp_file_set_data_and_size (file, ppm, size);
+		gp_file_set_data_and_size (file, (char *)ppm, size);
 
 	} else {	/* type is GP_FILE_TYPE_RAW */
 		size = w*h/comp_ratio;
@@ -396,7 +400,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		memcpy (rawdata, frame_data, size);
 		gp_file_set_mime_type (file, GP_MIME_RAW);
 		gp_file_set_name (file, filename);
-	        gp_file_set_data_and_size (file, rawdata, size);  
+	        gp_file_set_data_and_size (file, (char *)rawdata, size);  
 	}
 	/* Reset camera when done, for more graceful exit. */
 	if ((!(is_in_clip)&&(entry +1 == camera->pl->nb_entries)) 
@@ -446,13 +450,13 @@ camera_capture_preview (Camera *camera, CameraFile *file, GPContext *context)
 	/* Now put the data into a PPM image file. */
 	ppm = malloc (w * h * 3 + 256); 
 	if (!ppm) { return GP_ERROR_NO_MEMORY; }
-    	sprintf (ppm,
+    	sprintf ((char *)ppm,
 		"P6\n"
 		"# CREATOR: gphoto2, SQ905 library\n"
 		"%d %d\n"
 		"255\n", w, h);
-	ptr = ppm + strlen (ppm);	
-	size = strlen (ppm) + (w * h * 3);
+	ptr = ppm + strlen ((char*)ppm);	
+	size = strlen ((char*)ppm) + (w * h * 3);
 	GP_DEBUG ("size = %i\n", size);
 	switch (camera->pl->model) {
 	case SQ_MODEL_POCK_CAM:
@@ -464,17 +468,16 @@ camera_capture_preview (Camera *camera, CameraFile *file, GPContext *context)
 	}
 	
 	/* TO DO: 
-	 * Adapt postprocessing routine to work here, because results can   
-	 * vary greatly, depending both on lighting conditions and on 
+	 * Adapt some postprocessing routine to work here, because results 
+	 * can vary greatly, depending both on lighting conditions and on 
 	 * camera model.
 	 */
 
-	/* sq_postprocess(camera->pl,w, h, ptr, 1); */
 	gp_gamma_fill_table (gtable, .5); 
 	gp_gamma_correct_single (gtable, ptr, w * h); 
 	gp_file_set_mime_type (file, GP_MIME_PPM);
 	gp_file_set_name (file, filename); 
-	gp_file_set_data_and_size (file, ppm, size);
+	gp_file_set_data_and_size (file, (char *)ppm, size);
 
 	sq_reset(camera->port);
         sq_access_reg(camera->port, CAPTURE);
