@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 #include "config.h"
-#include <gphoto2-port-library.h>
+#include <gphoto2/gphoto2-port-library.h>
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -34,9 +34,9 @@
 
 #include <usb.h>
 
-#include <gphoto2-port.h>
-#include <gphoto2-port-result.h>
-#include <gphoto2-port-log.h>
+#include <gphoto2/gphoto2-port.h>
+#include <gphoto2/gphoto2-port-result.h>
+#include <gphoto2/gphoto2-port-log.h>
 
 #ifdef ENABLE_NLS
 #  include <libintl.h>
@@ -71,7 +71,7 @@ struct _GPPortPrivateLibrary {
 GPPortType
 gp_port_library_type (void)
 {
-        return (GP_PORT_USB);
+	return (GP_PORT_USB);
 }
 
 int
@@ -152,6 +152,7 @@ gp_port_library_list (GPPortInfoList *list)
 	bus = usb_get_busses();
 	while (bus) {
 		for (dev = bus->devices; dev; dev = dev->next) {
+			char *s;
 			/* Devices which are definitely not cameras. */
 			if (	(dev->descriptor.bDeviceClass == USB_CLASS_HUB)		||
 				(dev->descriptor.bDeviceClass == USB_CLASS_HID)		||
@@ -184,6 +185,8 @@ gp_port_library_list (GPPortInfoList *list)
 			 * and the Ricoh erronously reports it.
 			 */ 
 			sprintf (info.path, "usb:%s,%s", bus->dirname, dev->filename);
+			/* On MacOS X we might get usb:006,002-04a9-3139-00-00. */
+			s = strchr(info.path, '-');if (s) *s='\0';
 			CHECK (gp_port_info_list_append (list, info));
 		}
 		bus = bus->next;
@@ -224,6 +227,7 @@ gp_port_usb_open (GPPort *port)
 	int ret;
 	char name[64];
 
+	gp_log (GP_LOG_DEBUG,"libusb","gp_port_usb_open()");
 	if (!port || !port->pl->d)
 		return GP_ERROR_BAD_PARAMETERS;
 
@@ -253,10 +257,12 @@ gp_port_usb_open (GPPort *port)
 		if (ret < 0)
 			gp_port_set_error (port, _("Could not detach kernel driver '%s' of camera device."),name);
 	} else {
-		gp_port_set_error (port, _("Could not query kernel driver of device."));
+		if (errno != ENODATA) /* ENODATA - just no driver there */
+			gp_port_set_error (port, _("Could not query kernel driver of device."));
 	}
 #endif
 
+	gp_log (GP_LOG_DEBUG,"libusb","claiming interface %d", port->settings.usb.interface);
 	ret = usb_claim_interface (port->pl->dh,
 				   port->settings.usb.interface);
 	if (ret < 0) {
@@ -267,7 +273,6 @@ gp_port_usb_open (GPPort *port)
 			port->settings.usb.interface, "sdc2xx, stv680, spca50x");
 		return GP_ERROR_IO_USB_CLAIM;
 	}
-
 	return GP_OK;
 }
 
@@ -285,6 +290,18 @@ gp_port_usb_close (GPPort *port)
 		return (GP_ERROR_IO);
 	}
 
+#if 0
+	/* This does break Canon EOS and some PowerShots ... -Marcus */
+	/* This is only for our very special Canon cameras which need a good
+	 * whack after close, otherwise they get timeouts on reconnect.
+	 */
+	if (port->pl->d->descriptor.idVendor == 0x04a9) {
+		if (usb_reset (port->pl->dh) < 0) {
+			gp_port_set_error (port, _("Could not reset USB port (%m)."));
+			return (GP_ERROR_IO);
+		}
+	}
+#endif
 	if (usb_close (port->pl->dh) < 0) {
 		gp_port_set_error (port, _("Could not close USB port (%m)."));
 		return (GP_ERROR_IO);
@@ -358,14 +375,16 @@ gp_port_usb_check_int (GPPort *port, char *bytes, int size, int timeout)
 {
 	int ret;
 
-	if (!port || !port->pl->dh)
+	if (!port || !port->pl->dh || timeout < 0)
 		return GP_ERROR_BAD_PARAMETERS;
 
-	ret = usb_bulk_read(port->pl->dh, port->settings.usb.intep,
+	ret = usb_interrupt_read(port->pl->dh, port->settings.usb.intep,
 			     bytes, size, timeout);
-        if (ret < 0)
+        if (ret < 0) {
+		if (errno == EAGAIN)
+			return GP_ERROR_TIMEOUT;
 		return GP_ERROR_IO_READ;
-
+	}
         return ret;
 }
 
@@ -423,6 +442,35 @@ gp_port_usb_msg_interface_read_lib(GPPort *port, int request,
 }
 
 
+/* The next two functions support the nonstandard request types 0x21 (write) 
+ * and 0xa1 (read), which are occasionally needed. 
+ */
+
+static int
+gp_port_usb_msg_class_write_lib(GPPort *port, int request, 
+	int value, int index, char *bytes, int size)
+{
+	if (!port || !port->pl->dh)
+		return GP_ERROR_BAD_PARAMETERS;
+
+	return usb_control_msg(port->pl->dh, 
+		USB_TYPE_CLASS | USB_RECIP_INTERFACE,
+		request, value, index, bytes, size, port->timeout);
+}
+
+
+static int
+gp_port_usb_msg_class_read_lib(GPPort *port, int request, 
+	int value, int index, char *bytes, int size)
+{
+	if (!port || !port->pl->dh)
+		return GP_ERROR_BAD_PARAMETERS;
+
+	return usb_control_msg(port->pl->dh, 
+		USB_TYPE_CLASS | USB_RECIP_INTERFACE | USB_ENDPOINT_IN,
+		request, value, index, bytes, size, port->timeout);
+}
+
 /*
  * This function applys changes to the device.
  *
@@ -438,9 +486,21 @@ gp_port_usb_update (GPPort *port)
 {
 	int ret, ifacereleased = FALSE;
 
+	gp_log (GP_LOG_DEBUG, "libusb", "gp_port_usb_update(old int=%d, conf=%d, alt=%d), (new int=%d, conf=%d, alt=%d)",
+		port->settings.usb.interface,
+		port->settings.usb.config,
+		port->settings.usb.altsetting,
+		port->settings_pending.usb.interface,
+		port->settings_pending.usb.config,
+		port->settings_pending.usb.altsetting
+	);
 	if (!port)
 		return GP_ERROR_BAD_PARAMETERS;
 
+	if (port->pl->interface == -1) port->pl->interface = port->settings.usb.interface;
+	if (port->pl->config == -1) port->pl->config = port->settings.usb.config;
+	if (port->pl->altsetting == -1) port->pl->altsetting = port->settings.usb.altsetting;
+
 	/* The portname can also be changed with the device still fully closed. */
 	memcpy(&port->settings.usb.port, &port->settings_pending.usb.port,
 		sizeof(port->settings.usb.port));
@@ -451,7 +511,32 @@ gp_port_usb_update (GPPort *port)
 	memcpy(&port->settings.usb, &port->settings_pending.usb,
 		sizeof(port->settings.usb));
 
+	/* The interface changed. release the old, claim the new ... */
+	if (port->settings.usb.interface != port->pl->interface) {
+		gp_log (GP_LOG_DEBUG, "libusb", "changing interface %d -> %d",
+			port->pl->interface,
+			port->settings.usb.interface
+		);
+		if (usb_release_interface (port->pl->dh,
+					   port->pl->interface) < 0) {
+			gp_log (GP_LOG_DEBUG, "gphoto2-port-usb","releasing the iface for config failed.");
+			/* Not a hard error for now. -Marcus */
+		} else {
+			gp_log (GP_LOG_DEBUG,"libusb","claiming interface %d", port->settings.usb.interface);
+			ret = usb_claim_interface (port->pl->dh,
+						   port->settings.usb.interface);
+			if (ret < 0) {
+				gp_log (GP_LOG_DEBUG, "gphoto2-port-usb","reclaiming the iface for config failed.");
+				return GP_ERROR_IO_UPDATE;
+			}
+			port->pl->interface = port->settings.usb.interface;
+		}
+	}
 	if (port->settings.usb.config != port->pl->config) {
+		gp_log (GP_LOG_DEBUG, "libusb", "changing config %d -> %d",
+			port->pl->config,
+			port->settings.usb.config
+		);
 		/* This can only be changed with the interface released. 
 		 * This is a hard requirement since 2.6.12.
 		 */
@@ -465,11 +550,14 @@ gp_port_usb_update (GPPort *port)
 		ret = usb_set_configuration(port->pl->dh,
 				     port->settings.usb.config);
 		if (ret < 0) {
+#if 0 /* setting the configuration failure is not fatal */
 			gp_port_set_error (port,
 				_("Could not set config %d/%d (%m)"),
 				port->settings.usb.interface,
 				port->settings.usb.config);
 			return GP_ERROR_IO_UPDATE;	
+#endif
+			gp_log (GP_LOG_ERROR, "gphoto2-port-usb","setting configuration from %d to %d failed with ret = %d, but continue...", port->pl->config, port->settings.usb.config, ret);
 		}
 
 		gp_log (GP_LOG_DEBUG, "gphoto2-port-usb",
@@ -478,6 +566,7 @@ gp_port_usb_update (GPPort *port)
 			port->settings.usb.config);
 
 		if (ifacereleased) {
+			gp_log (GP_LOG_DEBUG,"libusb","claiming interface %d", port->settings.usb.interface);
 			ret = usb_claim_interface (port->pl->dh,
 						   port->settings.usb.interface);
 			if (ret < 0) {
@@ -496,9 +585,9 @@ gp_port_usb_update (GPPort *port)
 		ret = usb_set_altinterface(port->pl->dh, port->settings.usb.altsetting);
 		if (ret < 0) {
 			gp_port_set_error (port, 
-				_("Could not set altsetting "
-				"%d/%d (%m)"),
-				port->settings.usb.interface,
+				_("Could not set altsetting from %d "
+				"to %d (%m)"),
+				port->pl->altsetting,
 				port->settings.usb.altsetting);
 			return GP_ERROR_IO_UPDATE;
 		}
@@ -598,7 +687,9 @@ gp_port_usb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 			continue;
 
 		for (dev = bus->devices; dev; dev = dev->next) {
-			if ((devname[0] != '\0') && strcmp(devname, dev->filename))
+			if (	(devname[0] != '\0') &&
+				(dev->filename != strstr(dev->filename, devname))
+			)
 				continue;
 
 			if ((dev->descriptor.idVendor == idvendor) &&
@@ -617,6 +708,8 @@ gp_port_usb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 
 				/* Set the defaults */
 				if (dev->config) {
+					int i;
+
 					if (dev->config[config].interface[interface].altsetting[altsetting].bInterfaceClass
 					    == USB_CLASS_MASS_STORAGE) {
 						gp_log (GP_LOG_VERBOSE, "gphoto2-port-usb",
@@ -632,6 +725,15 @@ gp_port_usb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 					port->settings.usb.inep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_IN, USB_ENDPOINT_TYPE_BULK);
 					port->settings.usb.outep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_OUT, USB_ENDPOINT_TYPE_BULK);
 					port->settings.usb.intep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_IN, USB_ENDPOINT_TYPE_INTERRUPT);
+
+					port->settings.usb.maxpacketsize = 0;
+					gp_log (GP_LOG_DEBUG, "gphoto2-port-usb", "inep to look for is %02x", port->settings.usb.inep);
+					for (i=0;i<dev->config[config].interface[interface].altsetting[altsetting].bNumEndpoints;i++) {
+						if (port->settings.usb.inep == dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].bEndpointAddress) {
+							port->settings.usb.maxpacketsize = dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].wMaxPacketSize;
+							break;
+						}
+					}
 					gp_log (GP_LOG_VERBOSE, "gphoto2-port-usb",
 						"Detected defaults: config %d, "
 						"interface %d, altsetting %d, "
@@ -659,11 +761,97 @@ gp_port_usb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 	return GP_ERROR_IO_USB_FIND;
 }
 
+/* This function reads the Microsoft OS Descriptor and looks inside to
+ * find if it is a MTP device. This is the similar to the way that
+ * Windows Media Player 10 uses.
+ * It is documented to some degree on various internet pages.
+ */
+static int
+gp_port_usb_match_mtp_device(struct usb_device *dev,int *configno, int *interfaceno, int *altsettingno)
+{
+	char buf[1000], cmd;
+	int ret,i,i1,i2;
+	usb_dev_handle *devh;
+
+	/* All of them are "vendor specific" device class */
+#if 0
+	if ((dev->descriptor.bDeviceClass!=0xff) && (dev->descriptor.bDeviceClass!=0))
+		return 0;
+#endif
+
+	devh = usb_open (dev);
+	/* get string descriptor at 0xEE */
+	ret = usb_get_descriptor (devh, 0x03, 0xee, buf, sizeof(buf));
+	if (ret > 0) gp_log_data("get_MS_OSD",buf, ret);
+	if (ret < 10) goto errout;
+	if (!((buf[2] == 'M') && (buf[4]=='S') && (buf[6]=='F') && (buf[8]=='T')))
+		goto errout;
+	cmd = buf[16];
+	ret = usb_control_msg (devh, USB_ENDPOINT_IN|USB_RECIP_DEVICE|USB_TYPE_VENDOR, cmd, 0, 4, buf, sizeof(buf), 1000);
+	if (ret == -1) {
+		gp_log (GP_LOG_ERROR, "mtp matcher", "control message says %d\n", ret);
+		goto errout;
+	}
+	if (buf[0] != 0x28) {
+		gp_log (GP_LOG_ERROR, "mtp matcher", "ret is %d, buf[0] is %x\n", ret, buf[0]);
+		goto errout;
+	}
+	if (ret > 0) gp_log_data("get_MS_ExtDesc",buf, ret);
+	if ((buf[0x12] != 'M') || (buf[0x13] != 'T') || (buf[0x14] != 'P')) {
+		gp_log (GP_LOG_ERROR, "mtp matcher", "buf at 0x12 is %02x%02x%02x\n", buf[0x12], buf[0x13], buf[0x14]);
+		goto errout;
+	}
+	ret = usb_control_msg (devh, USB_ENDPOINT_IN|USB_RECIP_DEVICE|USB_TYPE_VENDOR, cmd, 0, 5, buf, sizeof(buf), 1000);
+	if (ret == -1) goto errout;
+	if (buf[0] != 0x28) {
+		gp_log (GP_LOG_ERROR, "mtp matcher", "ret is %d, buf[0] is %x\n", ret, buf[0]);
+		goto errout;
+	}
+	if (ret > 0) gp_log_data("get_MS_ExtProp",buf, ret);
+	if ((buf[0x12] != 'M') || (buf[0x13] != 'T') || (buf[0x14] != 'P')) {
+		gp_log (GP_LOG_ERROR, "mtp matcher", "buf at 0x12 is %02x%02x%02x\n", buf[0x12], buf[0x13], buf[0x14]);
+		goto errout;
+	}
+	usb_close (devh);
+
+	/* Now chose a nice interface for us to use ... Just take the first. */
+
+	if (dev->descriptor.bNumConfigurations > 1)
+		gp_log (GP_LOG_ERROR, "mtp matcher", "The device has %d configurations!\n", dev->descriptor.bNumConfigurations);
+	for (i = 0; i < dev->descriptor.bNumConfigurations; i++) {
+		struct usb_config_descriptor *config =
+			&dev->config[i];
+
+		if (config->bNumInterfaces > 1)
+			gp_log (GP_LOG_ERROR, "mtp matcher", "The configuration has %d interfaces!\n", config->bNumInterfaces);
+		for (i1 = 0; i1 < config->bNumInterfaces; i1++) {
+			struct usb_interface *interface =
+				&config->interface[i1];
+
+			if (interface->num_altsetting > 1)
+				gp_log (GP_LOG_ERROR, "mtp matcher", "The interface has %d altsettings!\n", interface->num_altsetting);
+			for (i2 = 0; i2 < interface->num_altsetting; i2++) {
+				*configno = i;
+				*interfaceno = i1;
+				*altsettingno = i2;
+				return 1;
+			}
+		}
+	}
+	return 1;
+errout:
+	usb_close (devh);
+	return 0;
+}
+
 static int
 gp_port_usb_match_device_by_class(struct usb_device *dev, int class, int subclass, int protocol, int *configno, int *interfaceno, int *altsettingno)
 {
 	int i, i1, i2;
 
+	if (class == 666) /* Special hack for MTP devices with MS OS descriptors. */
+		return gp_port_usb_match_mtp_device (dev, configno, interfaceno, altsettingno);
+
 	if (dev->descriptor.bDeviceClass == class &&
 	    (subclass == -1 ||
 	     dev->descriptor.bDeviceSubClass == subclass) &&
@@ -760,6 +948,8 @@ gp_port_usb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 				class, subclass, protocol);
 			/* Set the defaults */
 			if (dev->config) {
+				int i;
+
 				port->settings.usb.config = dev->config[config].bConfigurationValue;
 				port->settings.usb.interface = dev->config[config].interface[interface].altsetting[altsetting].bInterfaceNumber;
 				port->settings.usb.altsetting = dev->config[config].interface[interface].altsetting[altsetting].bAlternateSetting;
@@ -767,6 +957,14 @@ gp_port_usb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 				port->settings.usb.inep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_IN, USB_ENDPOINT_TYPE_BULK);
 				port->settings.usb.outep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_OUT, USB_ENDPOINT_TYPE_BULK);
 				port->settings.usb.intep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_IN, USB_ENDPOINT_TYPE_INTERRUPT);
+				port->settings.usb.maxpacketsize = 0;
+				gp_log (GP_LOG_DEBUG, "gphoto2-port-usb", "inep to look for is %02x", port->settings.usb.inep);
+				for (i=0;i<dev->config[config].interface[interface].altsetting[altsetting].bNumEndpoints;i++) {
+					if (port->settings.usb.inep == dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].bEndpointAddress) {
+						port->settings.usb.maxpacketsize = dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].wMaxPacketSize;
+						break;
+					}
+				}
 				gp_log (GP_LOG_VERBOSE, "gphoto2-port-usb",
 					"Detected defaults: config %d, "
 					"interface %d, altsetting %d, "
@@ -816,6 +1014,8 @@ gp_port_library_operations (void)
 	ops->msg_read   = gp_port_usb_msg_read_lib;
 	ops->msg_interface_write  = gp_port_usb_msg_interface_write_lib;
 	ops->msg_interface_read   = gp_port_usb_msg_interface_read_lib;
+	ops->msg_class_write  = gp_port_usb_msg_class_write_lib;
+	ops->msg_class_read   = gp_port_usb_msg_class_read_lib;
 	ops->find_device = gp_port_usb_find_device_lib;
 	ops->find_device_by_class = gp_port_usb_find_device_by_class_lib;
 
