@@ -132,7 +132,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 23 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 23 "ddb-txt.y"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -1364,7 +1364,7 @@ yyparse (file_name, al)
 
 
   /* User initialization code.  */
-#line 83 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 83 "ddb-txt.y"
 {
   lexer_reset(file_name);
   yyloc.begin.filename = yyloc.end.filename = file_name;
@@ -1559,7 +1559,7 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 142 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 142 "ddb-txt.y"
     {
 	  current_device_name = alloc_parse_string((yyvsp[(2) - (3)].str_val));
 	  /* printf("BEGIN_DEVICE <<%s>>\n", current_device_name); */
@@ -1570,7 +1570,7 @@ yyreduce:
     break;
 
   case 5:
-#line 158 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 158 "ddb-txt.y"
     {
 	  //printf("END_DEVICE <<%s>>\n", current_device_name);
 	  free(current_device_name);  current_device_name = NULL;
@@ -1582,7 +1582,7 @@ yyreduce:
     break;
 
   case 14:
-#line 189 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 189 "ddb-txt.y"
     {
 	  if (gpi_string_to_enum((yyvsp[(2) - (3)].str_val), &ca.device_type,
 				 gpi_gphoto_device_type_map)) {
@@ -1594,7 +1594,7 @@ yyreduce:
     break;
 
   case 15:
-#line 201 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 201 "ddb-txt.y"
     {
 	  const char *camlib_env = getenv(CAMLIBDIR_ENV);
 	  const char *camlibs = (camlib_env != NULL)?camlib_env:CAMLIBS;
@@ -1608,7 +1608,7 @@ yyreduce:
     break;
 
   case 17:
-#line 216 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 216 "ddb-txt.y"
     {
 	  if (gpi_string_to_enum((yyvsp[(2) - (3)].str_val), &ca.status,
 				 gpi_camera_driver_status_map)) {
@@ -1620,7 +1620,7 @@ yyreduce:
     break;
 
   case 30:
-#line 258 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 258 "ddb-txt.y"
     {
 	  if (gpi_string_or_to_flags((yyvsp[(1) - (1)].str_val), &ca.folder_operations,
 				     gpi_folder_operation_map)) {
@@ -1632,7 +1632,7 @@ yyreduce:
     break;
 
   case 31:
-#line 270 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 270 "ddb-txt.y"
     {
 	  if (gpi_string_or_to_flags((yyvsp[(1) - (1)].str_val), &ca.file_operations,
 				     gpi_file_operation_map)) {
@@ -1644,7 +1644,7 @@ yyreduce:
     break;
 
   case 32:
-#line 282 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 282 "ddb-txt.y"
     {
 	  if (gpi_string_or_to_flags((yyvsp[(1) - (1)].str_val),
 				     &ca.operations,
@@ -1657,21 +1657,21 @@ yyreduce:
     break;
 
   case 37:
-#line 301 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 301 "ddb-txt.y"
     {
 	  ca.port |= GP_PORT_DISK;
 	;}
     break;
 
   case 38:
-#line 304 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 304 "ddb-txt.y"
     {
 	  ca.port |= GP_PORT_PTPIP;
 	;}
     break;
 
   case 39:
-#line 311 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 311 "ddb-txt.y"
     {
 	  ca.port |= GP_PORT_SERIAL;
 	  /* Ideally: Prepare serial entry. */
@@ -1679,14 +1679,14 @@ yyreduce:
     break;
 
   case 40:
-#line 318 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 318 "ddb-txt.y"
     {
 	  /* Ideally: Add serial entry to database. */
         ;}
     break;
 
   case 42:
-#line 326 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 326 "ddb-txt.y"
     {
 	  if (speed_index < (sizeof(ca.speed)/sizeof(ca.speed[0]))) {
 	    ca.speed[speed_index++] = 0;
@@ -1697,7 +1697,7 @@ yyreduce:
     break;
 
   case 45:
-#line 342 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 342 "ddb-txt.y"
     {
 	  if (speed_index < (sizeof(ca.speed)/sizeof(ca.speed[0]))) {
 	    ca.speed[speed_index++] = (yyvsp[(1) - (1)].ui_val);
@@ -1706,7 +1706,7 @@ yyreduce:
     break;
 
   case 46:
-#line 356 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 356 "ddb-txt.y"
     {
 	  ca.port |= GP_PORT_USB;
 	  /* Ideally: Prepare USB entry for this camera */
@@ -1714,42 +1714,42 @@ yyreduce:
     break;
 
   case 47:
-#line 362 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 362 "ddb-txt.y"
     {
 	  /* Ideally: Commit prepared USB entry to database */
 	;}
     break;
 
   case 51:
-#line 380 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 380 "ddb-txt.y"
     {
 	  ca.usb_vendor = (yyvsp[(2) - (3)].ui_val);
 	;}
     break;
 
   case 52:
-#line 387 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 387 "ddb-txt.y"
     {
 	  ca.usb_product = (yyvsp[(2) - (3)].ui_val);
 	;}
     break;
 
   case 54:
-#line 395 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 395 "ddb-txt.y"
     {
 	  ca.usb_class = (yyvsp[(2) - (3)].ui_val);
 	;}
     break;
 
   case 57:
-#line 404 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 404 "ddb-txt.y"
     {
 	  ca.usb_subclass = (yyvsp[(2) - (3)].ui_val);
 	;}
     break;
 
   case 60:
-#line 413 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 413 "ddb-txt.y"
     {
 	  ca.usb_protocol = (yyvsp[(2) - (3)].ui_val);
 	;}
@@ -1977,7 +1977,7 @@ yyreturn:
 }
 
 
-#line 418 "../../../../libgphoto2/tests/ddb/ddb-txt.y"
+#line 418 "ddb-txt.y"
 
 
 
